@@ -12,7 +12,10 @@ my %feiertagsnamen = (
 		'hl3k' => 'Hl. 3 Koenige',
 		'romo' => 'Rosenmontag',
 		'fadi' => 'Faschingsdienstag',
+		'asmi' => 'Aschermittwoch',
+		'grdo' => 'Gruendonnerstag',
 		'karf' => 'Karfreitag',
+		'kars' => 'Karsamstag',
 		'osts' => 'Ostersonntag',
 		'ostm' => 'Ostermontag',
 		'pfis' => 'Pfingstsonntag',
@@ -22,10 +25,17 @@ my %feiertagsnamen = (
 		'1mai' => 'Maifeiertag',
 		'17ju' => 'Tag der deutschen Einheit (1954-1990)',
 		'mari' => 'Mariae Himmelfahrt',
+		'frie' => 'Augsburger Friedensfest (regional)',
 		'3okt' => 'Tag der deutschen Einheit',
 		'refo' => 'Reformationstag',
 		'alhe' => 'Allerheiligen',
 		'buss' => 'Buss- und Bettag',
+		'votr' => 'Volkstrauertag',
+		'toso' => 'Totensonntag',
+		'adv1' => '1. Advent',
+		'adv2' => '2. Advent',
+		'adv3' => '3. Advent',
+		'adv4' => '4. Advent',
 		'heil' => 'Heiligabend',
 		'wei1' => '1. Weihnachtstag',
 		'wei2' => '2. Weihnachtstag',
